#! /bin/sh

cd tests
. ./compat.sh

${DIR}/test_offsets_key_value
